import React, { useState, useEffect, useRef, lazy, Suspense } from 'react';
import { Routes, Route, useLocation } from 'react-router-dom';
import { Clock, DollarSign, Users, Calendar, BarChart2, Settings, PieChart, FileText, TrendingUp, Plus, Minus, Globe, BookOpen, ArrowLeft, ArrowRight, Share2, Calculator, Target, Clipboard, ListChecks } from 'lucide-react';
import { useTranslation, Trans } from 'react-i18next';
import { HelmetProvider } from 'react-helmet-async';
import CookieConsentBanner from './components/CookieConsentBanner';
import OpportunityCostSelector from './components/OpportunityCostSelector';
import OpportunityCostDisplay from './components/OpportunityCostDisplay';
import PotentialOutcomeInput from './components/PotentialOutcomeInput';
import MeetingROIChart from './components/MeetingROIChart';
import AgendaTab from './components/agenda/AgendaTab';
import { AgendaItem } from './types';
import Header from './components/Header';
import { usePageTracking, initializeGA } from './utils/analytics';
import SEO from './components/SEO';

// Move these types to separate file for better organization
type MeetingFrequency = 'one-time' | 'daily' | 'weekly' | 'monthly' | 'quarterly';

interface Decision {
  id: string;
  text: string;
}

interface Currency {
  code: string;
  symbol: string;
  name: string;
}

// Constants - moved outside of component for better memory usage
const CURRENCIES: Currency[] = [
  { code: 'USD', symbol: '$', name: 'US Dollar' },
  { code: 'EUR', symbol: '€', name: 'Euro' },
  { code: 'GBP', symbol: '£', name: 'British Pound' },
  { code: 'JPY', symbol: '¥', name: 'Japanese Yen' },
  { code: 'CAD', symbol: 'C$', name: 'Canadian Dollar' },
  { code: 'AUD', symbol: 'A$', name: 'Australian Dollar' },
  { code: 'INR', symbol: '₹', name: 'Indian Rupee' },
  { code: 'CNY', symbol: '¥', name: 'Chinese Yuan' },
];

// Lazy-loaded components with proper error boundaries
const ResultsPanel = lazy(() => import('./components/ResultsPanel'));
const Footer = lazy(() => import('./components/Footer'));
const MeetingTips = lazy(() => import('./components/MeetingTips'));
const PrivacyPolicy = lazy(() => import('./pages/PrivacyPolicy'));
const TermsOfUse = lazy(() => import('./pages/TermsOfUse'));
const BlogPage = lazy(() => import('./pages/BlogPage'));
const NotFound = lazy(() => import('./pages/NotFound'));

// Lightweight fallback components - optimized with fixed heights
const ResultsPanelFallback = () => <div className="bg-white rounded-lg p-6 animate-pulse h-96"></div>;
const FooterFallback = () => <div className="h-20" aria-hidden="true"></div>;
const MeetingTipsFallback = () => <div className="bg-white rounded-lg p-6 animate-pulse h-96"></div>;
const PageFallback = () => <div className="bg-white rounded-lg p-6 animate-pulse h-[70vh]"></div>;

const MainCalculator: React.FC = () => {
  const { t } = useTranslation();
  
  // Form state
  const [participants, setParticipants] = useState<number>(4);
  const [hourlyRate, setHourlyRate] = useState<number>(50);
  const [duration, setDuration] = useState<number>(60); // in minutes
  const [frequency, setFrequency] = useState<MeetingFrequency>('one-time');
  const [currency, setCurrency] = useState<Currency>(CURRENCIES[0]); // Default to USD
  
  // Opportunity cost state
  const [enableOpportunityCost, setEnableOpportunityCost] = useState<boolean>(false);
  const [opportunityCostProfile, setOpportunityCostProfile] = useState<string>('standard');
  const [customMultiplier, setCustomMultiplier] = useState<number>(1.5);
  
  // Potential outcome value state
  const [showPotentialOutcome, setShowPotentialOutcome] = useState<boolean>(false);
  const [potentialOutcome, setPotentialOutcome] = useState<number>(1000);
  const [outcomeType, setOutcomeType] = useState<string>('sales');
  const [probability, setProbability] = useState<number>(50);
  
  // Real-time tracking state
  const [isTracking, setIsTracking] = useState<boolean>(false);
  const [elapsedTime, setElapsedTime] = useState<number>(0); // in seconds
  const [currentCost, setCurrentCost] = useState<number>(0);
  const timerRef = useRef<number | null>(null);
  
  // Decisions/outcomes state
  const [decisions, setDecisions] = useState<Decision[]>([]);
  const [newDecision, setNewDecision] = useState<string>('');

  // Results state
  const [showResults, setShowResults] = useState<boolean>(false);
  const [activeTab, setActiveTab] = useState<string>('costs');
  
  // Ref for results panel
  const resultsPanelRef = useRef<HTMLDivElement>(null);
  const shareTabRef = useRef<HTMLDivElement>(null);
  
  // Cost calculations
  const minuteRate = (hourlyRate / 60) * participants;
  const totalCost = (duration * minuteRate);
  const costPerDecision = decisions.length > 0 ? totalCost / decisions.length : 0;
  
  // Get opportunity cost multiplier based on selected profile
  const getOpportunityCostMultiplier = () => {
    if (!enableOpportunityCost) return 0;
    
    switch (opportunityCostProfile) {
      case 'standard': return 1.5;
      case 'sales': return 2.5;
      case 'executive': return 3.0;
      case 'development': return 2.0;
      case 'custom': return customMultiplier;
      default: return 1.5;
    }
  };
  
  // Calculate opportunity costs
  const opportunityCostMultiplier = getOpportunityCostMultiplier();
  const opportunityCost = enableOpportunityCost ? (totalCost * opportunityCostMultiplier) - totalCost : 0;
  const totalWithOpportunityCost = totalCost + opportunityCost;
  
  // Real-time opportunity costs
  const currentOpportunityCost = enableOpportunityCost ? (currentCost * opportunityCostMultiplier) - currentCost : 0;
  const currentTotalWithOpportunityCost = currentCost + currentOpportunityCost;
  
  // Calculate potential outcome expected value
  const expectedOutcomeValue = showPotentialOutcome ? potentialOutcome * (probability / 100) : 0;
  const meetingROI = totalWithOpportunityCost > 0 ? ((expectedOutcomeValue - totalWithOpportunityCost) / totalWithOpportunityCost) * 100 : 0;
  
  // Annual projections
  const getAnnualMeetingCount = () => {
    switch (frequency) {
      case 'daily': return 260; // 5 work days * 52 weeks
      case 'weekly': return 52;
      case 'monthly': return 12;
      case 'quarterly': return 4;
      default: return 1;
    }
  };
  
  const annualCost = totalCost * getAnnualMeetingCount();
  const annualOpportunityCost = opportunityCost * getAnnualMeetingCount();
  const annualTotalWithOpportunityCost = totalWithOpportunityCost * getAnnualMeetingCount();
  const annualExpectedValue = expectedOutcomeValue * getAnnualMeetingCount();
  
  // Efficiency metrics
  const getEfficiencyScore = () => {
    const durationEfficiency = duration <= 30 ? 1 : duration <= 60 ? 0.8 : duration <= 90 ? 0.6 : 0.4;
    const decisionsEfficiency = decisions.length > 0 ? Math.min(decisions.length / (duration / 30), 1) : 0;
    
    // Factor in ROI if potential outcome is specified
    if (showPotentialOutcome && expectedOutcomeValue > 0) {
      const roiScore = Math.min(Math.max(meetingROI / 200, 0), 1); // Cap at 1 for 200%+ ROI
      return (durationEfficiency * 0.4 + decisionsEfficiency * 0.3 + roiScore * 0.3) * 100;
    }
    
    return (durationEfficiency * 0.6 + decisionsEfficiency * 0.4) * 100;
  };

  const efficiencyScore = getEfficiencyScore();
  
  // Optimization suggestions
  const getOptimizationSuggestions = () => {
    const suggestions = [];
    
    if (duration > 60) {
      suggestions.push("Consider shorter meetings (30-45 minutes) to maintain focus and productivity.");
    }
    
    if (participants > 8) {
      suggestions.push("Large meetings tend to be less effective. Consider reducing the number of participants to only essential team members.");
    }
    
    if (decisions.length === 0) {
      suggestions.push("No decisions recorded. Ensure meetings have clear agenda items and action points.");
    } else if (costPerDecision > 100) {
      suggestions.push("High cost per decision. Consider alternative formats like email updates for information sharing.");
    }
    
    if (frequency === 'weekly' && duration > 30) {
      suggestions.push("For recurring weekly meetings, shorter formats (15-30 min) often work better.");
    }
    
    if (enableOpportunityCost && opportunityCost > totalCost) {
      suggestions.push("High opportunity cost detected. Consider asynchronous alternatives or reducing meeting frequency.");
    }
    
    if (showPotentialOutcome) {
      if (meetingROI < 0) {
        suggestions.push("Meeting has negative ROI. Consider canceling or restructuring to increase value or reduce costs.");
      } else if (meetingROI < 50) {
        suggestions.push("Low ROI detected. Try reducing duration or participants to improve return.");
      }
    }
    
    return suggestions.length > 0 ? suggestions : ["Your meeting parameters look efficient. Great job!"];
  };
  
  // Handle timer for real-time cost tracking
  useEffect(() => {
    if (isTracking) {
      timerRef.current = window.setInterval(() => {
        setElapsedTime(prev => prev + 1);
        setCurrentCost(prev => prev + (minuteRate / 60));
      }, 1000);
    } else if (timerRef.current) {
      clearInterval(timerRef.current);
    }
    
    return () => {
      if (timerRef.current) clearInterval(timerRef.current);
    };
  }, [isTracking, minuteRate]);
  
  // Handle timer controls
  const startTimer = () => {
    setElapsedTime(0);
    setCurrentCost(0);
    setIsTracking(true);
  };
  
  const stopTimer = () => {
    setIsTracking(false);
    setShowResults(true);
    // When stopping the timer, switch to the share tab to encourage sharing
    if (currentCost > 0) {
      setTimeout(() => setActiveTab('share'), 500);
    }
  };
  
  const resetTimer = () => {
    setIsTracking(false);
    setElapsedTime(0);
    setCurrentCost(0);
    setShowResults(false);
    setDecisions([]);
  };
  
  // Handle adding decisions
  const addDecision = () => {
    if (newDecision.trim()) {
      setDecisions(prev => [...prev, { id: Date.now().toString(), text: newDecision }]);
      setNewDecision('');
    }
  };
  
  // Format time for display
  const formatTime = (seconds: number) => {
    const hrs = Math.floor(seconds / 3600);
    const mins = Math.floor((seconds % 3600) / 60);
    const secs = seconds % 60;
    return `${hrs.toString().padStart(2, '0')}:${mins.toString().padStart(2, '0')}:${secs.toString().padStart(2, '0')}`;
  };
  
  // Format currency for display - memoized for performance
  const formatCurrency = React.useCallback((amount: number) => {
    return new Intl.NumberFormat('en-US', { 
      style: 'currency', 
      currency: currency.code,
      minimumFractionDigits: currency.code === 'JPY' ? 0 : 2,
      maximumFractionDigits: currency.code === 'JPY' ? 0 : 2
    }).format(amount);
  }, [currency.code]);

  // Input controllers for number fields
  const handleIncrement = (setter: React.Dispatch<React.SetStateAction<number>>, value: number, step: number, max?: number) => {
    const newValue = value + step;
    if (max !== undefined && newValue > max) return;
    setter(newValue);
  };

  const handleDecrement = (setter: React.Dispatch<React.SetStateAction<number>>, value: number, step: number, min: number) => {
    const newValue = value - step;
    if (newValue < min) return;
    setter(newValue);
  };
  
  // Handle share button click - scroll to the share tab
  const handleShareButtonClick = () => {
    setActiveTab('share');
    
    // Add a small delay to allow for state update and rendering
    setTimeout(() => {
      // On mobile, we need to ensure both the panel and the share content are visible
      if (resultsPanelRef.current) {
        // First scroll the results panel into view
        resultsPanelRef.current.scrollIntoView({ behavior: 'smooth', block: 'start' });
        
        // Check if we're on mobile by window width
        const isMobile = window.innerWidth < 768;
        
        if (isMobile) {
          // Get the top position of the results panel
          const panelRect = resultsPanelRef.current.getBoundingClientRect();
          
          // For mobile, scroll a bit more to show the share content better
          window.scrollBy({
            top: panelRect.height * 0.2, // Scroll down a bit more to center the share section
            behavior: 'smooth'
          });
        }
        
        // For mobile devices: force focus on the share tab button
        const shareTabButton = document.querySelector('[aria-current="page"][aria-label="Share results tab"]');
        if (shareTabButton) {
          (shareTabButton as HTMLElement).focus();
        }
      }
    }, 100);
  };
  
  // Use React.memo for performance optimization to prevent unnecessary re-renders
  const MeetingParameters = React.memo(() => (
    <div className="bg-white shadow-lg rounded-lg p-6">
      <h2 className="text-xl font-semibold text-gray-800 mb-4 flex items-center">
        <Settings className="h-5 w-5 mr-2 text-blue-500" aria-hidden="true" />
        {t('calculator.parameters.title')}
      </h2>
      
      <div className="space-y-5">
        {/* Participants Input */}
        <div>
          <label htmlFor="participants" className="block text-sm font-medium text-gray-700 mb-1">
            {t('calculator.parameters.participants.label')}
          </label>
          <div className="flex items-center">
            <Users className="h-5 w-5 text-gray-400 mr-2" aria-hidden="true" />
            <div className="relative flex items-center w-full">
              <button 
                type="button"
                onClick={() => handleDecrement(setParticipants, participants, 1, 1)}
                className="absolute left-0 p-2 bg-blue-50 hover:bg-blue-100 border border-blue-200 rounded-l-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                aria-label="Decrease participants"
              >
                <Minus className="h-4 w-4 text-blue-600" aria-hidden="true" />
              </button>
              <input
                id="participants"
                type="number"
                inputMode="numeric"
                min="1"
                max="100"
                className="pl-10 pr-10 py-2 shadow-sm focus:ring-blue-500 focus:border-blue-500 block w-full text-center sm:text-sm border-gray-300 rounded-md"
                value={participants}
                onChange={(e) => setParticipants(Math.max(1, parseInt(e.target.value) || 1))}
                aria-label={t('calculator.parameters.participants.label')}
              />
              <button 
                type="button"
                onClick={() => handleIncrement(setParticipants, participants, 1, 100)}
                className="absolute right-0 p-2 bg-blue-50 hover:bg-blue-100 border border-blue-200 rounded-r-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                aria-label="Increase participants"
              >
                <Plus className="h-4 w-4 text-blue-600" aria-hidden="true" />
              </button>
            </div>
          </div>
          <div className="flex justify-between mt-2">
            <button 
              onClick={() => setParticipants(2)} 
              className={`text-xs px-2 py-1 rounded-full ${participants === 2 ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.participants.small')}
            >
              {t('calculator.parameters.participants.small')}
            </button>
            <button 
              onClick={() => setParticipants(5)} 
              className={`text-xs px-2 py-1 rounded-full ${participants === 5 ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.participants.medium')}
            >
              {t('calculator.parameters.participants.medium')}
            </button>
            <button 
              onClick={() => setParticipants(10)} 
              className={`text-xs px-2 py-1 rounded-full ${participants === 10 ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.participants.large')}
            >
              {t('calculator.parameters.participants.large')}
            </button>
            <button 
              onClick={() => setParticipants(20)} 
              className={`text-xs px-2 py-1 rounded-full ${participants === 20 ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.participants.team')}
            >
              {t('calculator.parameters.participants.team')}
            </button>
          </div>
        </div>
        
        {/* Hourly Rate Input */}
        <div>
          <label htmlFor="hourlyRate" className="block text-sm font-medium text-gray-700 mb-1">
            {t('calculator.parameters.hourlyRate.label')} ({currency.symbol})
          </label>
          <div className="flex items-center">
            <DollarSign className="h-5 w-5 text-gray-400 mr-2" aria-hidden="true" />
            <div className="relative flex items-center w-full">
              <button 
                type="button"
                onClick={() => handleDecrement(setHourlyRate, hourlyRate, 5, 1)}
                className="absolute left-0 p-2 bg-blue-50 hover:bg-blue-100 border border-blue-200 rounded-l-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                aria-label="Decrease hourly rate"
              >
                <Minus className="h-4 w-4 text-blue-600" aria-hidden="true" />
              </button>
              <input
                id="hourlyRate"
                type="number"
                inputMode="numeric"
                min="1"
                step="5"
                className="pl-10 pr-10 py-2 shadow-sm focus:ring-blue-500 focus:border-blue-500 block w-full text-center sm:text-sm border-gray-300 rounded-md"
                value={hourlyRate}
                onChange={(e) => setHourlyRate(Math.max(1, parseInt(e.target.value) || 1))}
                aria-label={t('calculator.parameters.hourlyRate.label')}
              />
              <button 
                type="button"
                onClick={() => handleIncrement(setHourlyRate, hourlyRate, 5)}
                className="absolute right-0 p-2 bg-blue-50 hover:bg-blue-100 border border-blue-200 rounded-r-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                aria-label="Increase hourly rate"
              >
                <Plus className="h-4 w-4 text-blue-600" aria-hidden="true" />
              </button>
            </div>
          </div>
          <div className="flex justify-between mt-2">
            <button 
              onClick={() => setHourlyRate(25)} 
              className={`text-xs px-2 py-1 rounded-full ${hourlyRate === 25 ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label="Set to 25 per hour"
            >
              {currency.symbol}25
            </button>
            <button 
              onClick={() => setHourlyRate(50)} 
              className={`text-xs px-2 py-1 rounded-full ${hourlyRate === 50 ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label="Set to 50 per hour"
            >
              {currency.symbol}50
            </button>
            <button 
              onClick={() => setHourlyRate(75)} 
              className={`text-xs px-2 py-1 rounded-full ${hourlyRate === 75 ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label="Set to 75 per hour"
            >
              {currency.symbol}75
            </button>
            <button 
              onClick={() => setHourlyRate(100)} 
              className={`text-xs px-2 py-1 rounded-full ${hourlyRate === 100 ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label="Set to 100 per hour"
            >
              {currency.symbol}100
            </button>
          </div>
        </div>
        
        {/* Duration Input */}
        <div>
          <label htmlFor="duration" className="block text-sm font-medium text-gray-700 mb-1">
            {t('calculator.parameters.duration.label')}
          </label>
          <div className="flex items-center">
            <Clock className="h-5 w-5 text-gray-400 mr-2" aria-hidden="true" />
            <div className="relative flex items-center w-full">
              <button 
                type="button"
                onClick={() => handleDecrement(setDuration, duration, 5, 5)}
                className="absolute left-0 p-2 bg-blue-50 hover:bg-blue-100 border border-blue-200 rounded-l-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                aria-label="Decrease duration"
              >
                <Minus className="h-4 w-4 text-blue-600" aria-hidden="true" />
              </button>
              <input
                id="duration"
                type="number"
                inputMode="numeric"
                min="5"
                step="5"
                className="pl-10 pr-10 py-2 shadow-sm focus:ring-blue-500 focus:border-blue-500 block w-full text-center sm:text-sm border-gray-300 rounded-md"
                value={duration}
                onChange={(e) => setDuration(Math.max(5, parseInt(e.target.value) || 5))}
                aria-label={t('calculator.parameters.duration.label')}
              />
              <button 
                type="button"
                onClick={() => handleIncrement(setDuration, duration, 5)}
                className="absolute right-0 p-2 bg-blue-50 hover:bg-blue-100 border border-blue-200 rounded-r-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                aria-label="Increase duration"
              >
                <Plus className="h-4 w-4 text-blue-600" aria-hidden="true" />
              </button>
            </div>
          </div>
          <div className="flex justify-between mt-2">
            <button 
              onClick={() => setDuration(15)} 
              className={`text-xs px-2 py-1 rounded-full ${duration === 15 ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.duration.15min')}
            >
              {t('calculator.parameters.duration.15min')}
            </button>
            <button 
              onClick={() => setDuration(30)} 
              className={`text-xs px-2 py-1 rounded-full ${duration === 30 ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.duration.30min')}
            >
              {t('calculator.parameters.duration.30min')}
            </button>
            <button 
              onClick={() => setDuration(45)} 
              className={`text-xs px-2 py-1 rounded-full ${duration === 45 ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.duration.45min')}
            >
              {t('calculator.parameters.duration.45min')}
            </button>
            <button 
              onClick={() => setDuration(60)} 
              className={`text-xs px-2 py-1 rounded-full ${duration === 60 ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.duration.60min')}
            >
              {t('calculator.parameters.duration.60min')}
            </button>
          </div>
        </div>
        
        {/* Frequency Selection */}
        <div>
          <label htmlFor="frequency" className="block text-sm font-medium text-gray-700 mb-1">{t('calculator.parameters.frequency.label')}</label>
          <div className="flex items-center">
            <Calendar className="h-5 w-5 text-gray-400 mr-2" aria-hidden="true" />
            <select
              id="frequency"
              className="py-2 shadow-sm focus:ring-blue-500 focus:border-blue-500 block w-full sm:text-sm border-gray-300 rounded-md appearance-none"
              value={frequency}
              onChange={(e) => setFrequency(e.target.value as MeetingFrequency)}
              aria-label={t('calculator.parameters.frequency.label')}
            >
              <option value="one-time">{t('calculator.parameters.frequency.oneTime')}</option>
              <option value="daily">{t('calculator.parameters.frequency.daily')}</option>
              <option value="weekly">{t('calculator.parameters.frequency.weekly')}</option>
              <option value="monthly">{t('calculator.parameters.frequency.monthly')}</option>
              <option value="quarterly">{t('calculator.parameters.frequency.quarterly')}</option>
            </select>
          </div>
          <div className="grid grid-cols-5 gap-1 mt-2">
            <button 
              onClick={() => setFrequency('one-time')} 
              className={`text-xs px-1 py-1 rounded-full ${frequency === 'one-time' ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.frequency.once')}
            >
              {t('calculator.parameters.frequency.once')}
            </button>
            <button 
              onClick={() => setFrequency('daily')} 
              className={`text-xs px-1 py-1 rounded-full ${frequency === 'daily' ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.frequency.daily')}
            >
              {t('calculator.parameters.frequency.daily')}
            </button>
            <button 
              onClick={() => setFrequency('weekly')} 
              className={`text-xs px-1 py-1 rounded-full ${frequency === 'weekly' ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.frequency.weekly')}
            >
              {t('calculator.parameters.frequency.weekly')}
            </button>
            <button 
              onClick={() => setFrequency('monthly')} 
              className={`text-xs px-1 py-1 rounded-full ${frequency === 'monthly' ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.frequency.monthly')}
            >
              {t('calculator.parameters.frequency.monthly')}
            </button>
            <button 
              onClick={() => setFrequency('quarterly')} 
              className={`text-xs px-1 py-1 rounded-full ${frequency === 'quarterly' ? 'bg-blue-100 text-blue-700' : 'bg-gray-100 text-gray-700 hover:bg-gray-200'}`}
              aria-label={t('calculator.parameters.frequency.quarterly')}
            >
              {t('calculator.parameters.frequency.quarterly')}
            </button>
          </div>
        </div>
        
        {/* Opportunity Cost Section */}
        <OpportunityCostSelector
          enableOpportunityCost={enableOpportunityCost}
          setEnableOpportunityCost={setEnableOpportunityCost}
          selectedProfile={opportunityCostProfile}
          setSelectedProfile={setOpportunityCostProfile}
          customMultiplier={customMultiplier}
          setCustomMultiplier={setCustomMultiplier}
        />
        
        {/* Potential Outcome Section */}
        <PotentialOutcomeInput 
          showPotentialOutcome={showPotentialOutcome}
          setShowPotentialOutcome={setShowPotentialOutcome}
          potentialOutcome={potentialOutcome}
          setPotentialOutcome={setPotentialOutcome}
          outcomeType={outcomeType}
          setOutcomeType={setOutcomeType}
          probability={probability}
          setProbability={setProbability}
          formatCurrency={formatCurrency}
          totalCost={totalCost}
          opportunityCost={opportunityCost}
          totalWithOpportunityCost={totalWithOpportunityCost}
        />
      </div>
      
      <div className="mt-6 bg-gray-50 p-4 rounded-md">
        <h3 className="text-sm font-medium text-gray-700 mb-2">{t('calculator.costEstimate.title')}</h3>
        <div className="text-2xl font-bold text-blue-600">{formatCurrency(totalCost)}</div>
        <p className="text-xs text-gray-700 mt-1">
          <Trans 
            i18nKey="calculator.costEstimate.basedOn"
            values={{
              participants,
              rate: formatCurrency(hourlyRate),
              duration
            }}
          />
        </p>
        
        {enableOpportunityCost && (
          <div className="mt-2 pt-2 border-t border-gray-200">
            <div className="flex justify-between items-center">
              <span className="text-sm text-gray-700">{t('calculator.costEstimate.withOpportunityCost')}</span>
              <span className="text-lg font-bold text-amber-600">{formatCurrency(totalWithOpportunityCost)}</span>
            </div>
            <p className="text-xs text-gray-500">
              <Trans 
                i18nKey="calculator.costEstimate.potentialLost"
                values={{ cost: formatCurrency(opportunityCost) }}
              />
            </p>
          </div>
        )}
        
        {showPotentialOutcome && (
          <div className="mt-2 pt-2 border-t border-gray-200">
            <div className="flex justify-between items-center">
              <span className="text-sm text-gray-700">{t('calculator.costEstimate.potentialOutcomeValue')}</span>
              <span className="text-lg font-bold text-green-600">{formatCurrency(expectedOutcomeValue)}</span>
            </div>
            <p className="text-xs text-gray-500">
              <Trans
                i18nKey="calculator.costEstimate.basedOnProbability"
                values={{ amount: formatCurrency(potentialOutcome), probability }}
              />
            </p>
            
            <div className="mt-2 flex justify-between items-center">
              <span className="text-sm font-medium text-gray-700">{t('calculator.costEstimate.meetingROI')}:</span>
              <span className={`text-lg font-bold ${meetingROI >= 0 ? 'text-green-600' : 'text-red-600'}`}>
                {meetingROI.toFixed(0)}%
              </span>
            </div>
          </div>
        )}
        
        {frequency !== 'one-time' && (
          <div className="mt-2 pt-2 border-t border-gray-200">
            <div className="text-sm font-medium">{t('calculator.costEstimate.annualCostEstimate')} <span className="text-blue-600 font-bold">{formatCurrency(annualCost)}</span></div>
            <p className="text-xs text-gray-700">
              <Trans
                i18nKey="calculator.costEstimate.basedOnAnnual"
                values={{ meetings: getAnnualMeetingCount() }}
              />
            </p>
            
            {enableOpportunityCost && (
              <div className="mt-1">
                <div className="text-sm font-medium">{t('calculator.costEstimate.annualTotal')} <span className="text-amber-600 font-bold">{formatCurrency(annualTotalWithOpportunityCost)}</span></div>
              </div>
            )}
            
            {showPotentialOutcome && (
              <div className="mt-1">
                <div className="text-sm font-medium">{t('calculator.costEstimate.annualOutcome')} <span className="text-green-600 font-bold">{formatCurrency(annualExpectedValue)}</span></div>
              </div>
            )}
          </div>
        )}
      </div>
      
      {/* Meeting ROI visualization when both opportunity cost and potential outcome are enabled */}
      {enableOpportunityCost && showPotentialOutcome && (
        <MeetingROIChart 
          meetingCost={totalCost}
          opportunityCost={opportunityCost}
          expectedValue={expectedOutcomeValue}
          formatCurrency={formatCurrency}
        />
      )}
      
      {/* Quick share button */}
      {showResults && (
        <div className="mt-4 flex justify-center">
          <button
            onClick={handleShareButtonClick}
            className="inline-flex items-center px-3 py-2 border border-transparent text-sm leading-4 font-medium rounded-md text-white bg-amber-600 hover:bg-amber-700 focus:outline-none focus:ring-2 focus:ring-amber-500"
          >
            <Share2 className="h-4 w-4 mr-1" />
            {t('calculator.shareWithBoss')}
          </button>
        </div>
      )}
    </div>
  ));
  
  return (
    <div className="min-h-screen bg-gradient-to-br from-gray-50 to-blue-50">
      <main className="max-w-7xl mx-auto py-6 sm:px-6 lg:px-8">
        <div className="px-4 py-6 sm:px-0">
          <div className="flex flex-col lg:flex-row gap-6">
            {/* Left Column: Input Form */}
            <div className="lg:w-1/3">
              <MeetingParameters />
            </div>
            
            {/* Middle Column: Real-time Counter & Agenda Management */}
            <div className="lg:w-1/3">
              <div className="bg-white shadow-lg rounded-lg p-6 mb-6">
                <h2 className="text-xl font-semibold text-gray-800 mb-4 flex items-center">
                  <Clock className="h-5 w-5 mr-2 text-blue-500" aria-hidden="true" />
                  {t('calculator.realTimeTracker.title')}
                </h2>
                
                <div className="flex flex-col items-center justify-center py-6">
                  <div className="text-4xl font-bold text-blue-600 mb-2">
                    {formatCurrency(isTracking ? currentCost : 0)}
                  </div>
                  {enableOpportunityCost && isTracking && (
                    <div className="text-amber-600 font-medium mb-2">
                      {formatCurrency(currentTotalWithOpportunityCost)} <span className="text-xs text-gray-500">(with opp. cost)</span>
                    </div>
                  )}
                  <div className="text-gray-700 text-lg mb-4">
                    {formatTime(elapsedTime)}
                  </div>
                  
                  <div className="grid grid-cols-3 gap-3 w-full max-w-xs">
                    {!isTracking ? (
                      <button
                        onClick={startTimer}
                        className="col-span-3 bg-green-700 hover:bg-green-800 text-white font-bold py-3 px-4 rounded-lg focus:outline-none focus:ring-2 focus:ring-green-500 focus:ring-opacity-50 text-lg shadow-md"
                        aria-label={t('calculator.realTimeTracker.startMeeting')}
                      >
                        {t('calculator.realTimeTracker.startMeeting')}
                      </button>
                    ) : (
                      <>
                        <button
                          onClick={stopTimer}
                          className="col-span-2 bg-red-700 hover:bg-red-800 text-white font-bold py-3 px-4 rounded-lg focus:outline-none focus:ring-2 focus:ring-red-500 focus:ring-opacity-50 shadow-md"
                          aria-label={t('calculator.realTimeTracker.endMeeting')}
                        >
                          {t('calculator.realTimeTracker.endMeeting')}
                        </button>
                        <button
                          onClick={resetTimer}
                          className="bg-gray-700 hover:bg-gray-800 text-white font-bold py-3 px-4 rounded-lg focus:outline-none focus:ring-2 focus:ring-gray-400 focus:ring-opacity-50 shadow-md"
                          aria-label={t('calculator.realTimeTracker.reset')}
                        >
                          {t('calculator.realTimeTracker.reset')}
                        </button>
                      </>
                    )}
                  </div>
                </div>
                
                <div className="mt-6">
                  <h3 className="text-sm font-medium text-gray-700 mb-2 flex items-center">
                    <FileText className="h-4 w-4 mr-1 text-blue-500" aria-hidden="true" /> 
                    {t('calculator.realTimeTracker.decisions.title')}
                  </h3>
                  
                  <div className="flex mb-2">
                    <input
                      type="text"
                      placeholder={t('calculator.realTimeTracker.decisions.placeholder')}
                      className="shadow-sm focus:ring-blue-500 focus:border-blue-500 block w-full sm:text-sm border-gray-300 rounded-l-md py-2 px-3"
                      value={newDecision}
                      onChange={(e) => setNewDecision(e.target.value)}
                      onKeyPress={(e) => e.key === 'Enter' && addDecision()}
                      aria-label="New decision or outcome"
                    />
                    <button
                      onClick={addDecision}
                      className="inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-r-md text-white bg-blue-700 hover:bg-blue-800 focus:outline-none focus:ring-2 focus:ring-blue-500"
                      aria-label={t('calculator.realTimeTracker.decisions.add')}
                    >
                      {t('calculator.realTimeTracker.decisions.add')}
                    </button>
                  </div>
                  
                  <div className="mt-2 max-h-40 overflow-y-auto">
                    {decisions.length > 0 ? (
                      <ul className="divide-y divide-gray-200" aria-label="Recorded decisions">
                        {decisions.map((decision) => (
                          <li key={decision.id} className="py-2 text-sm">
                            {decision.text}
                          </li>
                        ))}
                      </ul>
                    ) : (
                      <p className="text-sm text-gray-700 italic">{t('calculator.realTimeTracker.decisions.none')}</p>
                    )}
                  </div>
                </div>
                
                {enableOpportunityCost && showResults && (
                  <OpportunityCostDisplay 
                    totalCost={currentCost}
                    opportunityCost={currentOpportunityCost}
                    netCost={currentTotalWithOpportunityCost}
                    formatCurrency={formatCurrency}
                  />
                )}
              </div>
              
              {/* Agenda Management */}
              <div className="bg-white shadow-lg rounded-lg p-6">
                <h2 className="text-xl font-semibold text-gray-800 mb-4 flex items-center">
                  <Clipboard className="h-5 w-5 mr-2 text-blue-500" aria-hidden="true" />
                  {t('calculator.agenda.title')}
                </h2>
                
                <AgendaTab 
                  isTracking={isTracking} 
                  elapsedTime={elapsedTime} 
                  currentCost={currentCost} 
                  formatCurrency={formatCurrency} 
                  formatTime={formatTime}
                  showResults={showResults}
                />
              </div>
            </div>
            
            {/* Right Column: Results & Insights */}
            <div className="lg:w-1/3" ref={resultsPanelRef}>
              <div className="bg-white shadow-lg rounded-lg p-6">
                <h2 className="text-xl font-semibold text-gray-800 mb-4 flex items-center">
                  <BarChart2 className="h-5 w-5 mr-2 text-blue-500" aria-hidden="true" />
                  {t('calculator.analytics.title')}
                </h2>
                
                {showResults ? (
                  <Suspense fallback={<ResultsPanelFallback />}>
                    <ResultsPanel 
                      activeTab={activeTab}
                      setActiveTab={setActiveTab}
                      currentCost={currentCost}
                      minuteRate={minuteRate}
                      elapsedTime={elapsedTime}
                      decisions={decisions}
                      formatCurrency={formatCurrency}
                      frequency={frequency}
                      getAnnualMeetingCount={getAnnualMeetingCount}
                      efficiencyScore={efficiencyScore}
                      getOptimizationSuggestions={getOptimizationSuggestions}
                      participants={participants}
                      opportunityCost={currentOpportunityCost}
                      totalWithOpportunityCost={currentTotalWithOpportunityCost}
                      enableOpportunityCost={enableOpportunityCost}
                      showPotentialOutcome={showPotentialOutcome}
                      potentialOutcome={potentialOutcome}
                      probability={probability}
                      expectedOutcomeValue={expectedOutcomeValue}
                      meetingROI={meetingROI}
                      shareTabRef={shareTabRef}
                    />
                  </Suspense>
                ) : (
                  <div className="text-center py-12 px-4">
                    <Clock className="h-12 w-12 text-gray-300 mx-auto mb-4" aria-hidden="true" />
                    <h3 className="text-lg font-medium text-gray-900 mb-2">{t('calculator.analytics.noDataYet')}</h3>
                    <p className="text-sm text-gray-700 max-w-sm mx-auto">
                      {t('calculator.analytics.startTracking')}
                    </p>
                  </div>
                )}
              </div>
            </div>
          </div>
          
          {/* Meeting Tips & Tricks - Now always visible below the main sections */}
          <div className="mt-8">
            <Suspense fallback={<MeetingTipsFallback />}>
              <MeetingTips />
            </Suspense>
          </div>
        </div>
        
        {/* Footer with Ad Space */}
        <Suspense fallback={<FooterFallback />}>
          <Footer />
        </Suspense>
      </main>
    </div>
  );
};

const App: React.FC = () => {
  const location = useLocation();
  
  // Initialize Google Analytics
  useEffect(() => {
    initializeGA();
  }, []);
  
  // Track page views using custom hook
  usePageTracking();
  
  return (
    <HelmetProvider>
      <SEO />
      <Header />
      <CookieConsentBanner />
      <Routes>
        <Route path="/" element={<MainCalculator />} />
        <Route 
          path="/privacy" 
          element={
            <Suspense fallback={<PageFallback />}>
              <PrivacyPolicy />
            </Suspense>
          } 
        />
        <Route 
          path="/terms" 
          element={
            <Suspense fallback={<PageFallback />}>
              <TermsOfUse />
            </Suspense>
          } 
        />
        <Route 
          path="/blog" 
          element={
            <Suspense fallback={<PageFallback />}>
              <BlogPage />
            </Suspense>
          } 
        />
        <Route 
          path="*" 
          element={
            <Suspense fallback={<PageFallback />}>
              <NotFound />
            </Suspense>
          } 
        />
      </Routes>
    </HelmetProvider>
  );
};

export default App;